==> pqsdk-0.0.1.tar.gz: pqsdk-0.0.1/pqsdk/__main__.py <==
# coding=utf-8
import argparse
import sys
from .main import run_backtest
from pqsdk.utils.value_type_util import convert_to_type
import requests
import base64
import getpass
import pqsdk.utils.file_util as fu
import json
from .logger import log


def handle_config_command():
    # 提示用户输入用户名
    username = input("请输入用户名: ")
    if not username:
        print("用户名不能为空！")
        return

        # 提示用户输入密码
    password = getpass.getpass("请输入密码: ")
    if not password:
        print("密码不能为空！")
        return

    # 替换为你的实际客户端ID和密钥
    client_id = username
    client_secret = password

    # 将客户端ID和密钥用冒号连接，并编码为Base64
    credentials = f"{client_id}:{client_secret}"
    encoded_credentials = base64.b64encode(credentials.encode()).decode()

    # 设置请求URL和参数
    host = 'portal.tickertrading.com'
    url = f'http://{host}/api/auth/oauth2/token'
    params = {
        'grant_type': 'client_credentials',
        'scope': 'sdk'
    }

    # 发送POST请求
    headers = {
        'Authorization': f'Basic {encoded_credentials}',
        'Content-Type': 'application/x-www-form-urlencoded'
    }

    response = requests.post(url, params=params, headers=headers)

    # 响应内容
    result = response.json()['data']

    config_file = 'config.sdk.json'
    if fu.check_path_exists(config_file):
        # 更新配置文件
        with open(config_file, 'r', encoding='utf-8') as f:
            sdk_config = json.loads(f.read())
        sdk_config['token'] = result['access_token']
        sdk_config['audience'] = client_id
        sdk_config['host'] = host
        print("配件文件已经更新")
    else:
        # 创建配置文件
        data = {
            "host": host,
            "audience": client_id,
            "token": result['access_token']
        }
        with open(config_file, 'w', encoding='utf-8') as f:
            json.dump(data, f)
        log.info("新的配置创建完成")

    # 检查响应状态码
    if response.status_code == 200:
        pass
    else:
        print(f"请求失败，状态码：{response.status_code}")


def handle_config_info_command():
    config_file = 'config.sdk.json'
    if fu.check_path_exists(config_file):
        with open(config_file, 'r', encoding='utf-8') as f:
            sdk_config = json.loads(f.read())

        print("配置信息:")
        for k, v in sdk_config.items():
            print(f"    {k} = {v}")
    else:
        print("未找到配置文件. 请先运行命令进行配置: pqsdk config")


def main():
    parser = argparse.ArgumentParser(description='PQ SDK Command Line Interface')
    parser.add_argument('command', choices=['backtest', 'config'], help='The command to execute')
    parser.add_argument('subcommand', choices=['info'], nargs='?', help='The subcommand to execute (optional)')
    parser.add_argument('-f', dest='file', metavar='file path', help='回测脚本文件路径')
    parser.add_argument('-plot', action='store_true', help='是否绘图')
    parser.add_argument('-p', dest='param', action='append', nargs=1, metavar='key=value',
                        help='自定义的参数, 格式: -p key=value, 等号之间不能有空格')

    args = parser.parse_args()

    # 将 -p 传递的参数转换为字典, args.param的原始格式：[['key1=value1'], ['key2=value2']]
    params = {}
    if args.param is not None:
        for kv in args.param:
            key, value = kv[0].replace(" ", "").split('=')
            params[key] = convert_to_type(value)

    if args.command == 'backtest':
        # 执行回测
        run_backtest(args.file, params, args.plot)
    elif args.command == 'config':
        if args.subcommand == 'info':
            handle_config_info_command()
        else:
            handle_config_command()

    else:
        parser.print_help()
        sys.exit(1)


if __name__ == "__main__":
    main()

==> pqsdk-0.0.12.tar.gz: pqsdk-0.0.12/pqsdk/__main__.py <==
# coding=utf-8
import argparse
import sys
from .main import run_backtest
from pqsdk.utils.value_type_util import convert_to_type
import requests
import base64
import getpass
import pqsdk.utils.file_util as fu
import json
from .logger import log


def handle_config_command():
    # 提示用户输入用户名
    username = input("请输入用户名: ")
    if not username:
        print("用户名不能为空！")
        return

        # 提示用户输入密码
    password = getpass.getpass("请输入密码: ")
    if not password:
        print("密码不能为空！")
        return

    # 替换为你的实际客户端ID和密钥
    client_id = username
    client_secret = password

    # 将客户端ID和密钥用冒号连接，并编码为Base64
    credentials = f"{client_id}:{client_secret}"
    encoded_credentials = base64.b64encode(credentials.encode()).decode()

    # 设置请求URL和参数
    host = 'portal.tickertrading.com'
    url = f'http://{host}/api/auth/oauth2/token'
    params = {
        'grant_type': 'client_credentials',
        'scope': 'sdk'
    }

    # 发送POST请求
    headers = {
        'Authorization': f'Basic {encoded_credentials}',
        'Content-Type': 'application/x-www-form-urlencoded'
    }

    response = requests.post(url, params=params, headers=headers)

    # 响应内容
    result = response.json()['data']

    config_file = 'config.sdk.json'
    if fu.check_path_exists(config_file):
        # 更新配置文件
        with open(config_file, 'r', encoding='utf-8') as f:
            sdk_config = json.loads(f.read())
        sdk_config['token'] = result['access_token']
        sdk_config['audience'] = client_id
        sdk_config['host'] = host
        print("配件文件已经更新")
    else:
        # 创建配置文件
        data = {
            "host": host,
            "audience": client_id,
            "token": result['access_token']
        }
        with open(config_file, 'w', encoding='utf-8') as f:
            json.dump(data, f)
        log.info("新的配置创建完成")

    # 检查响应状态码
    if response.status_code == 200:
        pass
    else:
        print(f"请求失败，状态码：{response.status_code}")


def handle_config_info_command():
    config_file = 'config.sdk.json'
    if fu.check_path_exists(config_file):
        with open(config_file, 'r', encoding='utf-8') as f:
            sdk_config = json.loads(f.read())

        print("配置信息:")
        for k, v in sdk_config.items():
            print(f"    {k} = {v}")
    else:
        print("未找到配置文件. 请先运行命令进行配置: pqsdk config")


def main():
    parser = argparse.ArgumentParser(description='PQ SDK Command Line Interface')
    parser.add_argument('command', choices=['backtest', 'config'], help='The command to execute')
    parser.add_argument('subcommand', choices=['info'], nargs='?', help='The subcommand to execute (optional)')
    parser.add_argument('-f', dest='file', metavar='file path', help='回测脚本文件路径')
    parser.add_argument('-plot', action='store_true', help='是否绘图')
    parser.add_argument('-save_results', action='store_true', help='是否保存结果到csv文件')
    parser.add_argument('-save_orders', action='store_true', help='是否保存委托到csv文件')
    parser.add_argument('-p', dest='param', action='append', nargs=1, metavar='key=value',
                        help='自定义的参数, 格式: -p key=value, 等号之间不能有空格')

    args = parser.parse_args()

    # 将 -p 传递的参数转换为字典, args.param的原始格式：[['key1=value1'], ['key2=value2']]
    params = {}
    if args.param is not None:
        for kv in args.param:
            key, value = kv[0].replace(" ", "").split('=')
            params[key] = convert_to_type(value)

    if args.command == 'backtest':
        # 执行回测
        run_backtest(args.file, params, args.plot, args.save_results, args.save_orders)
    elif args.command == 'config':
        if args.subcommand == 'info':
            handle_config_info_command()
        else:
            handle_config_command()

    else:
        parser.print_help()
        sys.exit(1)


if __name__ == "__main__":
    main()
